@@ -2,5 +2,5 @@ from enum import Enum
 
 
 class Phase(Enum):
-    stable = 'stable'
-    beta = 'beta'
+    stable = "stable"
+    beta = "beta"
